@@ -239,9 +239,8 @@ class Site(Server):
 		if not self.exists():
 			raise EasyEngineException
 
-		# Write certificate
-		command = 'echo "%(certificate_code)s" >> %(path)s/cert/%(domain)s.crt' % dict(
-			certificate_code = self._certificate_code,
+		# Remove
+		command = 'rm -rf  %(path)s/cert/%(domain)s.crt' % dict(
 			path             = self._path,
 			domain           = self._domain
 		)
@@ -282,8 +281,17 @@ class Site(Server):
 			stdout.readlines()
 
 			return self.response(True)
+		else:
+			# Write certificate
+			command = 'echo "%(certificate_code)s" >> %(path)s/cert/%(domain)s.crt' % dict(
+				certificate_code = self._certificate_code,
+				path             = self._path,
+				domain           = self._domain
+			)
+			stdin, stdout, stderr = self.execute(command)
+			stdout.readlines()
 
-		return self.response(False)
+			return self.response(False)
 
 	def uninstall_ssl(self, domain):
 		self._domain = validate_domain(domain)
